import * as elements from '@yellicode/elements';
import * as opts from './options';
import { CodeWriter, TextWriter } from '@yellicode/templating';
/**
 * Provides code writing functionality specific for TypeScript.
 */
export declare class TypeScriptWriter extends CodeWriter {
    private typeNameProvider;
    maxCommentWidth: number;
    constructor(writer: TextWriter, options?: opts.WriterOptions);
    /**
    * Writes an indented block of code, wrapped in opening and closing brackets.
    * @param contents A callback function that writes the contents.
    */
    writeCodeBlock(contents: (writer: TypeScriptWriter) => void): void;
    /**
     * Writes a block of code, wrapped in a class declaration and opening and closing brackets.
     * This function does not write class members.
     * @param cls The class.
     * @param contents A callback function that writes the class contents.
     * @param options An optional ClassOptions object.
     */
    writeClassBlock(cls: elements.Class, contents: (writer: TypeScriptWriter, cls: elements.Class) => void, options?: opts.ClassOptions): void;
    /**
      * Writes a block of code, wrapped in an interface declaration and opening and closing brackets.
      * This function does not write interface members.
      * @param iface The interface.
      * @param contents A callback function that writes the interface contents.
      * @param options An optional InterfaceOptions object.
      */
    writeInterfaceBlock(iface: elements.Interface, contents: (writer: TypeScriptWriter, cls: elements.Interface) => void, options?: opts.InterfaceOptions): void;
    /**
     * Writes a class or interface property.
     * @param property The property to write.
     * @param options An optional PropertyOptions object.
     */
    writeProperty(property: elements.Property, options?: opts.PropertyOptions): void;
    /**
     * Writes a full enumeration, including members.
     * @param element The enumeration.
     * @param options An optional EnumerationOptions object.
     */
    writeEnumeration(enumeration: elements.Enumeration, options: opts.EnumOptions): void;
    /**
     * Writes a string literal type from a specified enumeration. Example: 'type Easing = 'ease-in' | 'ease-out' | 'ease-in-out';'
     * @param enumeration The enumeration.
     * @param prefix An optional prefix, such as 'export'.
     */
    writeStringLiteralType(enumeration: elements.Enumeration, prefix?: string): void;
    /**
     * Writes a function declaration without a body.
     * @param operation The operation.
     * @param options An optional FunctionOptions object.
     */
    writeFunctionDeclaration(operation: elements.Operation, options?: opts.FunctionOptions): void;
    /**
    * Writes a block of code, wrapped in an function declaration and opening and closing brackets.      *
    * @param operation The operation.
    * @param contents A callback that writes the operation contents.
    * @param options An optional FunctionOptions object.
    */
    writeFunctionBlock(operation: elements.Operation, contents: (writer: TypeScriptWriter, op: elements.Operation) => void, options?: opts.FunctionOptions): void;
    private writeFunctionStart(operation, options?);
    private writeInOutParameters(parameters, optionalityModifier?);
    private getParameterTypeName(parameter);
    private writeAccessModifier(visibilityKind);
    private writeGeneralizations(generalizations, additional);
    private writeInterfaceRealizations(realizations, additional);
    private pushJsDocLinesFromComments(comments, lines);
    private pushJsDocLinesForParameters(parameters, lines);
    private getJsDocLineForParameter(parameter);
    writeJsDocDescription(comments: elements.Comment[]): void;
    writeJsDocDescription(text: string): void;
    writeJsDocParagraph(text: string): void;
    writeJsDocLines(lines: string[]): void;
    private static getAccessModifierString(visibility);
    private getTypeName(typedElement);
    private joinWrite<TItem>(collection, separator, getStringFunc);
}
